#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class AFTStrongTrendMO : Indicator
	{
		private double weekHi, weekLo, weekCl, weekKnt, priorWeekHi, priorWeekLo, priorWeekCl, value1;
		private Series<int> Trend;
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"AFT Strong Trend Monthly Filter as published in the February 2024 Stocks and Commodities article titled ""Trend Identification By Price And Time Filtering"" by Alfred François Tagher";
				Name										= "AFTStrongTrendMO";
				Calculate									= Calculate.OnPriceChange;
				IsOverlay									= false;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				UpColor										= Brushes.Green;
				DnColor										= Brushes.Magenta;
				AddPlot(new Stroke(Brushes.Orange, 2), PlotStyle.Bar, "TrendPlot");
			}
			else if (State == State.DataLoaded)
			{
				weekKnt = 0;
				Trend = new Series<int>(this);
			}
		}

		protected override void OnBarUpdate()
		{
			if (CurrentBar < 1)
				return;
			if (Time[0].Month != Time[1].Month)
			{
				value1 = Close[1];
				if (value1 > priorWeekHi)
				{
					if (Trend[2] <= 0)
						Trend[1] = 1;
					else
						Trend[1] = Trend[2] + 1;
				}
				else if (value1 < priorWeekLo)
				{
					if (Trend[2] >= 0)
						Trend[1] = -1;
					else
						Trend[1] = Trend[2] - 1;
				}
				else
				{
					if (Trend[2] >= 1)
						Trend[1] = Trend[1] + 1;
					if (Trend[2] <= -1)
						Trend[1] = Trend[2] - 1;
				}
				priorWeekHi = weekHi;
				priorWeekLo = weekLo;
				weekHi = High[0];
				weekLo = Low[0];
				weekKnt = weekKnt + 1;
			}
			else
			{
				if (High[0] > weekHi)
					weekHi = High[0];
				if (Low[0] < weekLo)
					weekLo = Low[0];
				if (Trend[2] >= 1)
					Trend[1] = Trend[2] + 1;
				if (Trend[2] <= -1)
					Trend[1] = Trend[2] - 1;
			}
			if (weekKnt > 1)
			{
				TrendPlot[1] = Trend[1];
				if (Trend[1] >= 1)
					PlotBrushes[0][1] = UpColor;
				if (Trend[1] <= -1)
					PlotBrushes[0][1] = DnColor;
			}
		}

		#region Properties
		[XmlIgnore()]
		[Display(Name = "Up Color", GroupName = "NinjaScriptParameters", Order = 0)]
		public Brush UpColor
		{ get; set; }
		
		[Browsable(false)]
		public string UpColorSerialize
		{
			get { return Serialize.BrushToString(UpColor); }
   			set { UpColor = Serialize.StringToBrush(value); }
		}
		
		[XmlIgnore()]
		[Display(Name = "Down Color", GroupName = "NinjaScriptParameters", Order = 1)]
		public Brush DnColor
		{ get; set; }
		
		[Browsable(false)]
		public string DnColorSerialize
		{
			get { return Serialize.BrushToString(DnColor); }
   			set { DnColor = Serialize.StringToBrush(value); }
		}

		[Browsable(false)]
		[XmlIgnore]
		public Series<double> TrendPlot
		{
			get { return Values[0]; }
		}
		#endregion

	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private AFTStrongTrendMO[] cacheAFTStrongTrendMO;
		public AFTStrongTrendMO AFTStrongTrendMO()
		{
			return AFTStrongTrendMO(Input);
		}

		public AFTStrongTrendMO AFTStrongTrendMO(ISeries<double> input)
		{
			if (cacheAFTStrongTrendMO != null)
				for (int idx = 0; idx < cacheAFTStrongTrendMO.Length; idx++)
					if (cacheAFTStrongTrendMO[idx] != null &&  cacheAFTStrongTrendMO[idx].EqualsInput(input))
						return cacheAFTStrongTrendMO[idx];
			return CacheIndicator<AFTStrongTrendMO>(new AFTStrongTrendMO(), input, ref cacheAFTStrongTrendMO);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.AFTStrongTrendMO AFTStrongTrendMO()
		{
			return indicator.AFTStrongTrendMO(Input);
		}

		public Indicators.AFTStrongTrendMO AFTStrongTrendMO(ISeries<double> input )
		{
			return indicator.AFTStrongTrendMO(input);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.AFTStrongTrendMO AFTStrongTrendMO()
		{
			return indicator.AFTStrongTrendMO(Input);
		}

		public Indicators.AFTStrongTrendMO AFTStrongTrendMO(ISeries<double> input )
		{
			return indicator.AFTStrongTrendMO(input);
		}
	}
}

#endregion
