#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class AFTStrongTrendWK : Indicator
	{
		private double weekHi, weekLo, weekCl, weekKnt, priorWeekHi, priorWeekLo, priorWeekCl, value1;
		private Series<int> Trend;
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"AFT Strong Trend Weekly Filter as published in the February 2024 Stocks and Commodities article titled ""Trend Identification By Price And Time Filtering"" by Alfred François Tagher";
				Name										= "AFTStrongTrendWK";
				Calculate									= Calculate.OnPriceChange;
				IsOverlay									= false;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				UpColor										= Brushes.Green;
				DnColor										= Brushes.Red;
				AddPlot(new Stroke(Brushes.Green, 2), PlotStyle.Bar, "TrendPlot");
			}
			else if (State == State.DataLoaded)
			{
				weekKnt = 0;
				Trend = new Series<int>(this);
			}
		}

		protected override void OnBarUpdate()
		{
			if (CurrentBar < 1)
				return;
			if ((Time[0].DayOfWeek < Time[1].DayOfWeek && Time[1].DayOfWeek != DayOfWeek.Friday) || Time[0].DayOfWeek == DayOfWeek.Friday)
			{
				if (Time[0].DayOfWeek == DayOfWeek.Friday)
						value1 = Close[0];
				else
					value1 = Close[1];
				if (value1 > priorWeekHi)
				{
					if (Trend[1] <= 0)
						Trend[0] = 1;
					else
						Trend[0] = Trend[1] + 1;
				}
				else if (value1 < priorWeekLo)
				{
					if (Trend[1] >= 0)
						Trend[0] = -1;
					else
						Trend[0] = Trend[1] - 1;
				}
				else
				{
					if (Trend[1] >= 1)
						Trend[0] = Trend[1] + 1;
					if (Trend[1] <= -1)
						Trend[0] = Trend[1] - 1;
				}
				priorWeekHi = weekHi;
				priorWeekLo = weekLo;
				weekKnt = weekKnt + 1;
			}
			else
			{
				if (Trend[1] >= 1)
					Trend[0] = Trend[1] + 1;
				if (Trend[1] <= -1)
					Trend[0] = Trend[1] - 1;
			}
			if (Time[0].DayOfWeek < Time[1].DayOfWeek)
			{
				weekHi = High[0];
				weekLo = Low[0];
			}
			if (High[0] > weekHi)
				weekHi = High[0];
			if (Low[0] < weekLo)
				weekLo = Low[0];
			if (weekKnt > 1)
			{
				TrendPlot[0] = Trend[0];
				if (Trend[0] >= 1)
					PlotBrushes[0][0] = UpColor;
				if (Trend[0] <= -1)
					PlotBrushes[0][0] = DnColor;
			}
		}

		#region Properties
		[XmlIgnore()]
		[Display(Name = "Up Color", GroupName = "NinjaScriptParameters", Order = 0)]
		public Brush UpColor
		{ get; set; }
		
		[Browsable(false)]
		public string UpColorSerialize
		{
			get { return Serialize.BrushToString(UpColor); }
   			set { UpColor = Serialize.StringToBrush(value); }
		}
		
		[XmlIgnore()]
		[Display(Name = "Down Color", GroupName = "NinjaScriptParameters", Order = 1)]
		public Brush DnColor
		{ get; set; }
		
		[Browsable(false)]
		public string DnColorSerialize
		{
			get { return Serialize.BrushToString(DnColor); }
   			set { DnColor = Serialize.StringToBrush(value); }
		}

		[Browsable(false)]
		[XmlIgnore]
		public Series<double> TrendPlot
		{
			get { return Values[0]; }
		}

		#endregion

	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private AFTStrongTrendWK[] cacheAFTStrongTrendWK;
		public AFTStrongTrendWK AFTStrongTrendWK()
		{
			return AFTStrongTrendWK(Input);
		}

		public AFTStrongTrendWK AFTStrongTrendWK(ISeries<double> input)
		{
			if (cacheAFTStrongTrendWK != null)
				for (int idx = 0; idx < cacheAFTStrongTrendWK.Length; idx++)
					if (cacheAFTStrongTrendWK[idx] != null &&  cacheAFTStrongTrendWK[idx].EqualsInput(input))
						return cacheAFTStrongTrendWK[idx];
			return CacheIndicator<AFTStrongTrendWK>(new AFTStrongTrendWK(), input, ref cacheAFTStrongTrendWK);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.AFTStrongTrendWK AFTStrongTrendWK()
		{
			return indicator.AFTStrongTrendWK(Input);
		}

		public Indicators.AFTStrongTrendWK AFTStrongTrendWK(ISeries<double> input )
		{
			return indicator.AFTStrongTrendWK(input);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.AFTStrongTrendWK AFTStrongTrendWK()
		{
			return indicator.AFTStrongTrendWK(Input);
		}

		public Indicators.AFTStrongTrendWK AFTStrongTrendWK(ISeries<double> input )
		{
			return indicator.AFTStrongTrendWK(input);
		}
	}
}

#endregion
